==> iggy-0.6.0-incubating-src.tar.gz: iggy-0.6.0-incubating-src/foreign/node/src/wire/offset/delete-offset.command.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import { deserializeVoidResponse } from '../../client/client.utils.js';
import type { CommandResponse } from '../../client/client.type.js';
import type { GetOffset } from './get-offset.command.js';
import { wrapCommand } from '../command.utils.js';
import { serializeGetOffset } from './offset.utils.js';
import { COMMAND_CODE } from '../command.code.js';


export type DeleteOffset = GetOffset;

export const DELETE_OFFSET = {
  code: COMMAND_CODE.DeleteConsumerOffset,

  serialize: ({ streamId, topicId, consumer, partitionId = 0 }: DeleteOffset) => {
    return serializeGetOffset(streamId, topicId, consumer, partitionId);
  },

  deserialize: deserializeVoidResponse
};


export const deleteOffset = wrapCommand<DeleteOffset, boolean>(DELETE_OFFSET);

==> iggy-0.7.0-incubating-src.tar.gz: iggy-0.7.0-incubating-src/foreign/node/src/wire/offset/delete-offset.command.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import { deserializeVoidResponse } from '../../client/client.utils.js';
import type { GetOffset } from './get-offset.command.js';
import { wrapCommand } from '../command.utils.js';
import { serializeGetOffset } from './offset.utils.js';
import { COMMAND_CODE } from '../command.code.js';


/**
 * Parameters for the delete offset command.
 * Same as GetOffset parameters.
 */
export type DeleteOffset = GetOffset;

/**
 * Delete offset command definition.
 * Removes a stored consumer offset.
 */
export const DELETE_OFFSET = {
  code: COMMAND_CODE.DeleteConsumerOffset,

  serialize: ({ streamId, topicId, consumer, partitionId = 0 }: DeleteOffset) => {
    return serializeGetOffset(streamId, topicId, consumer, partitionId);
  },

  deserialize: deserializeVoidResponse
};


/**
 * Executable delete offset command function.
 */
export const deleteOffset = wrapCommand<DeleteOffset, boolean>(DELETE_OFFSET);
